..
    This file is part of Invenio.
    Copyright (C) 2017-2019 CERN.

    Invenio is free software; you can redistribute it and/or modify it
    under the terms of the MIT License; see LICENSE file for more details.


Changes
=======

Version 1.0.0a5 (released 06-28-2019)
-------------------------------------

- Dependencies update
- API refactoring by making it more node-centric
- License change to MIT

Version 1.0.0a4 (released 02-11-2017)
-------------------------------------

- Initial public release.
